@@ -4,11 +4,13 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package Mail::Message;
-use base 'Mail::Reporter';
+use parent 'Mail::Reporter';
 
 use strict;
 use warnings;
 
+use Log::Report     'mail-message', import => [ qw/__x error info panic trace/ ];
+
 use Mail::Message::Part            ();
 use Mail::Message::Head::Complete  ();
 use Mail::Message::Construct       ();
@@ -17,18 +19,8 @@ use Mail::Message::Body::Lines     ();
 use Mail::Message::Body::Multipart ();
 use Mail::Message::Body::Nested    ();
 
-use Carp;
 use Scalar::Util   qw/weaken blessed/;
 
-BEGIN {
-	unless($ENV{HARNESS_ACTIVE}) {   # no tests during upgrade
-		# v3 splits Mail::Box in a few distributions
-		eval { require Mail::Box };
-		my $v = $Mail::Box::VERSION || 3;
-		$v >= 3 or die "You need to upgrade the Mail::Box module";
-	}
-}
-
 #--------------------
 =chapter NAME
 
@@ -37,15 +29,15 @@ Mail::Message - general message object
 =chapter SYNOPSIS
 
   use Mail::Box::Manager;
-  my $mgr     = Mail::Box::Manager->new;
-  my $folder  = $mgr->open(folder => 'InBox');
-  my $msg     = $folder->message(2);    # $msg is a Mail::Message now
+  my $mgr    = Mail::Box::Manager->new;
+  my $folder = $mgr->open(folder => 'InBox');
+  my $msg    = $folder->message(2);    # $msg is a Mail::Message now
 
   my $subject = $msg->subject;         # The message's subject
   my @cc      = $msg->cc;              # List of Mail::Address'es
 
-  my $head    = $msg->head;    # Mail::Message::Head
-  my $body    = $msg->decoded;    # Mail::Message::Body
+  my Mail::Message::Head $head = $msg->head;
+  my Mail::Message::Body $body = $msg->decoded;
   $msg->decoded->print($outfile);
 
   # Send a simple email
@@ -53,13 +45,11 @@ Mail::Message - general message object
     To             => 'you@example.com',
     From           => 'me@example.com',
     Subject        => "My subject",
-    data           => "Some plain text content",
+    data           => "Some plain text content"
   )->send(via => 'postfix');
 
-  my $msg       = Mail::Message->read(\*STDIN);
-  my $reply_msg = $msg->reply(...);
-  my $frwd_msg  = $msg->forward(...);
-  my $bounce    = $msg->bounce(...);
+  my $reply_msg = Mail::Message->reply(...);
+  my $frwd_msg  = Mail::Message->forward(...);
 
 =chapter DESCRIPTION
 
@@ -69,10 +59,6 @@ the messages in mailboxes (folders) is implemented in this class.  Methods
 which are related to folders is implemented in the Mail::Box::Message
 extension.
 
-B<This is a maintenance release for the old interface>.  Read
-F<https://github.com/markov2/perl5-Mail-Box/wiki/> how
-to move towards version 4.
-
 The main methods are M<get()>, to get information from a message header
 field, and M<decoded()> to get the intended content of a message.
 But there are many more which can assist your program.
@@ -138,13 +124,13 @@ body data is decoded or used for transmission.
 =default deleted false
 Is the file deleted from the start?
 
-=option  labels ARRAY|HASH
+=option  labels \@pairs|\%settings
 =default labels +{}
-Initial values of the labels.  In case of Mail::Box::Message's, this
-shall reflect the state the message is in.  For newly constructed
-Mail::Message's, this may be anything you want, because M<coerce()>
-will take care of the folder specifics once the message is added to one.
-
+Initial %settings of the labels.  In case of Mail::Box::Message type
+objectss, this shall reflect the state the message is in inside the
+folder.  For newly constructed Mail::Message objectss, this may be
+anything you want, because M<coerce()> will take care of the folder
+specifics once the message is added to one.
 =cut
 
 sub init($)
@@ -238,7 +224,7 @@ sub clone(@)
 	my ($head, $body) = ($self->head, $self->body);
 	$head = $head->clone unless $args{shallow} || $args{shallow_head};
 	$body = $body->clone unless $args{shallow} || $args{shallow_body};
-	my $clone  = Mail::Message->new(head => $head, body => $body, $self->logSettings);
+	my $clone  = Mail::Message->new(head => $head, body => $body);
 
 	my $labels = $self->labels;
 	my %labels = %$labels;
@@ -353,7 +339,7 @@ sub print(;$)
 	$self->head->print($out);
 	my $body = $self->body;
 	$body->print($out) if $body;
-	ref $self ne __PACKAGE__ or $body->endsOnNewline or $out->print("\n");
+	$body->endsOnNewline or $out->print("\n");
 	$self;
 }
 
@@ -480,9 +466,7 @@ sub head(;$)
 	{	delete $self->{MM_head};
 		return undef;
 	}
-
-	blessed $head && $head->isa('Mail::Message::Head')
-		or $self->log(INTERNAL => "wrong type of head ($head) for message $self");
+	blessed $head && $head->isa('Mail::Message::Head') or panic;
 
 	$head->message($self);
 
@@ -544,7 +528,7 @@ or better:
 =cut
 
 sub study($)
-{	my $head = shift->head or return;
+{	my $head = $_[0]->head or return;
 	scalar $head->study(@_);    # return only last
 }
 
@@ -742,9 +726,7 @@ sub body(;$@)
 		$body->message(undef) if defined $body;
 		return $body;
 	}
-
-	blessed $rawbody && $rawbody->isa('Mail::Message::Body')
-		or $self->log(INTERNAL => "wrong type of body for message $rawbody");
+	blessed $rawbody && $rawbody->isa('Mail::Message::Body') or panic;
 
 	# Bodies of real messages must be encoded for safe transmission.
 	# Message parts will get encoded on the moment the whole multipart
@@ -840,6 +822,7 @@ each part of the message; each part as P<RECURSE> would return.
   my @parts = $msg->parts;           # returns ($msg)
   my $parts = $msg->parts('ACTIVE'); # returns ()
 
+=error select parts via '$what'?
 =cut
 
 sub parts(;$)
@@ -859,13 +842,13 @@ sub parts(;$)
 	: $what eq 'DELETED'  ? (grep $_->isDeleted, @parts)
 	: $what eq 'ALL'      ? @parts
 	: $recurse            ? @parts
-	:    confess "Select parts via $what?";
+	:    error __x"select parts via '{what}'?", what => $what;
 }
 
 #--------------------
 =section Flags
 
-=method modified [$flag]
+=method modified [BOOLEAN]
 Returns (optionally after setting) whether this message is flagged as
 being modified.  See isModified().
 =cut
@@ -1015,9 +998,8 @@ value is given, M<delete()> is called.
 
 sub deleted(;$)
 {	my $self = shift;
-
 	@_ ? $self->label(deleted => shift)
-		: $self->label('deleted')   # compat 2.036
+	   : $self->label('deleted')   # compat 2.036
 }
 
 =method labelsToStatus
@@ -1110,8 +1092,11 @@ Simpler replacement for the previous two lines:
 
   my $coerced = $folder->addMessage($message);
 
-=error coercion starts with some object
-=error Cannot coerce a $class object into a $class object
+=error coercion starts with some object, not '$type'.
+=error please install MIME::Entity.
+=error please install Mail::Internet.
+=error please install Email::Simple.
+=error cannot coerce a $type object into a $me object.
 =cut
 
 my $mail_internet_converter;
@@ -1122,7 +1107,7 @@ sub coerce($@)
 {	my ($class, $message) = @_;
 
 	blessed $message
-		or die "coercion starts with some object";
+		or error __x"coercion starts with some object, not '{type}'.", type => ref $message // $message ;
 
 	return $message
 		if ref $message eq $class;
@@ -1136,7 +1121,7 @@ sub coerce($@)
 	if($message->isa('MIME::Entity'))
 	{	unless($mime_entity_converter)
 		{	eval {require Mail::Message::Convert::MimeEntity};
-			$@ and confess "Install MIME::Entity";
+			$@ and error __x"please install MIME::Entity.";
 			$mime_entity_converter = Mail::Message::Convert::MimeEntity->new;
 		}
 
@@ -1146,8 +1131,8 @@ sub coerce($@)
 
 	elsif($message->isa('Mail::Internet'))
 	{	unless($mail_internet_converter)
-		{	eval {require Mail::Message::Convert::MailInternet};
-			$@ and confess "Install Mail::Internet";
+		{	eval { require Mail::Message::Convert::MailInternet };
+			$@ and error __x"please install Mail::Internet.";
 			$mail_internet_converter = Mail::Message::Convert::MailInternet->new;
 		}
 
@@ -1158,7 +1143,7 @@ sub coerce($@)
 	elsif($message->isa('Email::Simple'))
 	{	unless($email_simple_converter)
 		{	eval {require Mail::Message::Convert::EmailSimple};
-			$@ and confess "Install Email::Simple";
+			$@ and error __x"please install Email::Simple.";
 			$email_simple_converter = Mail::Message::Convert::EmailSimple->new;
 		}
 
@@ -1171,7 +1156,7 @@ sub coerce($@)
 	}
 
 	else
-	{	$class->log(INTERNAL =>  "Cannot coerce a ". ref($message) . " object into a ". __PACKAGE__." object");
+	{	error __x"cannot coerce a {type} object into a {me} object.", type => ref $message, me => __PACKAGE__;
 	}
 
 	$message->{MM_modified}  ||= 0;
@@ -1202,12 +1187,10 @@ which returns a body-class based on the header.
 sub readFromParser($;$)
 {	my ($self, $parser, $bodytype) = @_;
 
-	my $head = $self->readHead($parser) // Mail::Message::Head::Complete->new(
-		message => $self, field_type => $self->{MM_field_type}, $self->logSettings);
-
-	my $body = $self->readBody($parser, $head, $bodytype)
-		or return;
+	my $head = $self->readHead($parser) //
+		Mail::Message::Head::Complete->new(message => $self, field_type => $self->{MM_field_type});
 
+	my $body = $self->readBody($parser, $head, $bodytype) or return;
 	$self->head($head);
 	$self->storeBody($body);
 	$self;
@@ -1222,7 +1205,7 @@ sub readHead($;$)
 {	my ($self, $parser, $headtype) = @_;
 	$headtype //= $self->{MM_head_type} // 'Mail::Message::Head::Complete';
 
-	$headtype->new(message => $self, field_type => $self->{MM_field_type}, $self->logSettings)
+	$headtype->new(message => $self, field_type => $self->{MM_field_type})
 		->read($parser);
 }
 
@@ -1250,7 +1233,7 @@ sub readBody($$;$$)
 	my $body;
 	if($bodytype->isDelayed)
 	{	# autodetect charset after transfer decoding.
-		$body = $bodytype->new(message => $self, charset => undef, $self->logSettings);
+		$body = $bodytype->new(message => $self, charset => undef);
 	}
 	else
 	{	my $ct   = $head->get('Content-Type', 0);
@@ -1269,7 +1252,7 @@ sub readBody($$;$$)
 				if $enc =~ m/^(?:none|7bit|8bit|binary)$/i && ! $bodytype->isNested;
 		}
 
-		$body = $bodytype->new(message => $self, checked => $self->{MM_trusted}, charset => undef, $self->logSettings);
+		$body = $bodytype->new(message => $self, checked => $self->{MM_trusted}, charset => undef);
 		$body->contentInfoFrom($head);
 	}
 
