@@ -4,11 +4,13 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package Mail::Message::TransferEnc::Binary;
-use base 'Mail::Message::TransferEnc';
+use parent 'Mail::Message::TransferEnc';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw// ];
+
 #--------------------
 =chapter NAME
 
